@@ -18,8 +18,9 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA 
  */
-#ifndef IDEVICE_H
-#define IDEVICE_H
+
+#ifndef __DEVICE_H
+#define __DEVICE_H
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
