@@ -95,21 +95,19 @@ static instproxy_error_t instproxy_error(property_list_service_error_t err)
  * Connects to the installation_proxy service on the specified device.
  *
  * @param device The device to connect to
- * @param port Destination port (usually given by lockdownd_start_service).
+ * @param service The service descriptor returned by lockdownd_start_service.
  * @param client Pointer that will be set to a newly allocated
  *     instproxy_client_t upon successful return.
  *
  * @return INSTPROXY_E_SUCCESS on success, or an INSTPROXY_E_* error value
  *     when an error occured.
  */
-instproxy_error_t instproxy_client_new(idevice_t device, uint16_t port, instproxy_client_t *client)
+instproxy_error_t instproxy_client_new(idevice_t device, lockdownd_service_descriptor_t service, instproxy_client_t *client)
 {
-	if (!device)
-		return INSTPROXY_E_INVALID_ARG;
-
 	property_list_service_client_t plistclient = NULL;
-	if (property_list_service_client_new(device, port, &plistclient) != PROPERTY_LIST_SERVICE_E_SUCCESS) {
-		return INSTPROXY_E_CONN_FAILED;
+	instproxy_error_t err = instproxy_error(property_list_service_client_new(device, service, &plistclient));
+	if (err != INSTPROXY_E_SUCCESS) {
+		return err;
 	}
 
 	instproxy_client_t client_loc = (instproxy_client_t) malloc(sizeof(struct instproxy_client_private));
@@ -762,9 +760,9 @@ plist_t instproxy_client_options_new()
  * @param client_options The client options to modify.
  * @param ... KEY, VALUE, [KEY, VALUE], NULL
  *
- * @note The keys and values passed are expected to be strings, except for
- *       "ApplicationSINF" and "iTunesMetadata" expecting a plist node of type
- *       PLIST_DATA as value, or "SkipUninstall" needing int as value.
+ * @note The keys and values passed are expected to be strings, except for the
+ *       keys "ApplicationSINF", "iTunesMetadata", "ReturnAttributes" which are
+ *       expecting a plist_t node as value and "SkipUninstall" expects int.
  */
 void instproxy_client_options_add(plist_t client_options, ...)
 {
@@ -778,7 +776,7 @@ void instproxy_client_options_add(plist_t client_options, ...)
 		if (!strcmp(key, "SkipUninstall")) {
 			int intval = va_arg(args, int);
 			plist_dict_insert_item(client_options, key, plist_new_bool(intval));
-		} else if (!strcmp(key, "ApplicationSINF") || !strcmp(key, "iTunesMetadata")) {
+		} else if (!strcmp(key, "ApplicationSINF") || !strcmp(key, "iTunesMetadata") || !strcmp(key, "ReturnAttributes")) {
 			plist_t plistval = va_arg(args, plist_t);
 			if (!plistval) {
 				free(key);
