@@ -27,7 +27,7 @@
 #include "device_link_service.h"
 #include "debug.h"
 
-#define MBACKUP2_VERSION_INT1 100
+#define MBACKUP2_VERSION_INT1 300
 #define MBACKUP2_VERSION_INT2 0
 
 #define IS_FLAG_SET(x, y) ((x & y) == y)
@@ -65,7 +65,7 @@ static mobilebackup2_error_t mobilebackup2_error(device_link_service_error_t err
  * Connects to the mobilebackup2 service on the specified device.
  *
  * @param device The device to connect to.
- * @param port Destination port (usually given by lockdownd_start_service).
+ * @param service The service descriptor returned by lockdownd_start_service.
  * @param client Pointer that will be set to a newly allocated
  *     mobilebackup2_client_t upon successful return.
  *
@@ -73,14 +73,14 @@ static mobilebackup2_error_t mobilebackup2_error(device_link_service_error_t err
  *     if one or more parameter is invalid, or MOBILEBACKUP2_E_BAD_VERSION
  *     if the mobilebackup2 version on the device is newer.
  */
-mobilebackup2_error_t mobilebackup2_client_new(idevice_t device, uint16_t port,
+mobilebackup2_error_t mobilebackup2_client_new(idevice_t device, lockdownd_service_descriptor_t service,
 						mobilebackup2_client_t * client)
 {
-	if (!device || port == 0 || !client || *client)
+	if (!device || !service || service->port == 0 || !client || *client)
 		return MOBILEBACKUP2_E_INVALID_ARG;
 
 	device_link_service_client_t dlclient = NULL;
-	mobilebackup2_error_t ret = mobilebackup2_error(device_link_service_client_new(device, port, &dlclient));
+	mobilebackup2_error_t ret = mobilebackup2_error(device_link_service_client_new(device, service, &dlclient));
 	if (ret != MOBILEBACKUP2_E_SUCCESS) {
 		return ret;
 	}
@@ -279,13 +279,13 @@ mobilebackup2_error_t mobilebackup2_send_raw(mobilebackup2_client_t client, cons
 
 	*bytes = 0;
 
-	idevice_connection_t conn = client->parent->parent->connection;
+	service_client_t raw = client->parent->parent->parent;
 
 	int bytes_loc = 0;
 	uint32_t sent = 0;
 	do {
 		bytes_loc = 0;
-		idevice_connection_send(conn, data+sent, length-sent, (uint32_t*)&bytes_loc);
+		service_send(raw, data+sent, length-sent, (uint32_t*)&bytes_loc);
 		if (bytes_loc <= 0)
 			break;
 		sent += bytes_loc;
@@ -321,7 +321,7 @@ mobilebackup2_error_t mobilebackup2_receive_raw(mobilebackup2_client_t client, c
 	if (!client || !client->parent || !data || (length == 0) || !bytes)
 		return MOBILEBACKUP2_E_INVALID_ARG;
 
-	idevice_connection_t conn = client->parent->parent->connection;
+	service_client_t raw = client->parent->parent->parent;
 
 	*bytes = 0;
 
@@ -329,7 +329,7 @@ mobilebackup2_error_t mobilebackup2_receive_raw(mobilebackup2_client_t client, c
 	uint32_t received = 0;
 	do {
 		bytes_loc = 0;
-		idevice_connection_receive(conn, data+received, length-received, (uint32_t*)&bytes_loc);
+		service_receive(raw, data+received, length-received, (uint32_t*)&bytes_loc);
 		if (bytes_loc <= 0) break;
 		received += bytes_loc;
 	} while (received < length);
