@@ -19,8 +19,9 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA 
  */
-#ifndef MOBILESYNC_H
-#define MOBILESYNC_H
+
+#ifndef __MOBILESYNC_H
+#define __MOBILESYNC_H
 
 #include "libimobiledevice/mobilesync.h"
 #include "device_link_service.h"
