@@ -88,20 +88,17 @@ static sbservices_error_t sbservices_error(property_list_service_error_t err)
  * Connects to the springboardservices service on the specified device.
  *
  * @param device The device to connect to.
- * @param port Destination port (usually given by lockdownd_start_service).
+ * @param service The service descriptor returned by lockdownd_start_service.
  * @param client Pointer that will point to a newly allocated
  *     sbservices_client_t upon successful return.
  *
  * @return SBSERVICES_E_SUCCESS on success, SBSERVICES_E_INVALID_ARG when
  *     client is NULL, or an SBSERVICES_E_* error code otherwise.
  */
-sbservices_error_t sbservices_client_new(idevice_t device, uint16_t port, sbservices_client_t *client)
+sbservices_error_t sbservices_client_new(idevice_t device, lockdownd_service_descriptor_t service, sbservices_client_t *client)
 {
-	if (!device)
-		return SBSERVICES_E_INVALID_ARG;
-
 	property_list_service_client_t plistclient = NULL;
-	sbservices_error_t err = sbservices_error(property_list_service_client_new(device, port, &plistclient));
+	sbservices_error_t err = sbservices_error(property_list_service_client_new(device, service, &plistclient));
 	if (err != SBSERVICES_E_SUCCESS) {
 		return err;
 	}
