@@ -19,8 +19,8 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef USERPREF_H
-#define USERPREF_H
+#ifndef __USERPREF_H
+#define __USERPREF_H
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
