@@ -54,13 +54,12 @@ static void print_usage(int argc, char **argv)
 int main(int argc, char *argv[])
 {
 	lockdownd_client_t client = NULL;
-	idevice_t phone = NULL;
+	idevice_t device = NULL;
 	idevice_error_t ret = IDEVICE_E_UNKNOWN_ERROR;
 	int i;
-	char udid[41];
+	const char* udid = NULL;
 	time_t setdate = 0;
 	plist_t node = NULL;
-	udid[0] = 0;
 	uint64_t datetime = 0;
 	time_t rawtime;
 	struct tm * tmp;
@@ -79,7 +78,7 @@ int main(int argc, char *argv[])
 				print_usage(argc, argv);
 				return 0;
 			}
-			strcpy(udid, argv[i]);
+			udid = argv[i];
 			continue;
 		}
 		else if (!strcmp(argv[i], "-s") || !strcmp(argv[i], "--set")) {
@@ -124,24 +123,18 @@ int main(int argc, char *argv[])
 		}
 	}
 
-	if (udid[0] != 0) {
-		ret = idevice_new(&phone, udid);
-		if (ret != IDEVICE_E_SUCCESS) {
+	ret = idevice_new(&device, udid);
+	if (ret != IDEVICE_E_SUCCESS) {
+		if (udid) {
 			printf("No device found with udid %s, is it plugged in?\n", udid);
-			return -1;
-		}
-	}
-	else
-	{
-		ret = idevice_new(&phone, NULL);
-		if (ret != IDEVICE_E_SUCCESS) {
+		} else {
 			printf("No device found, is it plugged in?\n");
-			return -1;
 		}
+		return -1;
 	}
 
-	if (LOCKDOWN_E_SUCCESS != lockdownd_client_new_with_handshake(phone, &client, "idevicedate")) {
-		idevice_free(phone);
+	if (LOCKDOWN_E_SUCCESS != lockdownd_client_new_with_handshake(device, &client, "idevicedate")) {
+		idevice_free(device);
 		return -1;
 	}
 
@@ -150,7 +143,21 @@ int main(int argc, char *argv[])
 		/* get time value from device */
 		if(lockdownd_get_value(client, NULL, "TimeIntervalSince1970", &node) == LOCKDOWN_E_SUCCESS) {
 			if (node) {
-				plist_get_uint_val(node, &datetime);
+				switch (plist_get_node_type(node)) {
+				case PLIST_UINT:
+					plist_get_uint_val(node, &datetime);
+					break;
+				case PLIST_REAL:
+					{
+					double rv = 0;
+					plist_get_real_val(node, &rv);
+					datetime = rv;
+					}
+					break;
+				default:
+					fprintf(stderr, "Unexpected node type for 'TimeIntervalSince1970'\n");
+					break;
+				}
 				plist_free(node);
 				node = NULL;
 
@@ -176,7 +183,7 @@ int main(int argc, char *argv[])
 	}
 
 	lockdownd_client_free(client);
-	idevice_free(phone);
+	idevice_free(device);
 
 	return 0;
 }
