@@ -36,10 +36,10 @@ int main(int argc, char **argv)
 	idevice_t device = NULL;
 	lockdownd_client_t lckd = NULL;
 	screenshotr_client_t shotr = NULL;
-	uint16_t port = 0;
+	lockdownd_service_descriptor_t service = NULL;
 	int result = -1;
 	int i;
-	char *udid = NULL;
+	const char *udid = NULL;
 
 	/* parse cmdline args */
 	for (i = 1; i < argc; i++) {
@@ -53,7 +53,7 @@ int main(int argc, char **argv)
 				print_usage(argc, argv);
 				return 0;
 			}
-			udid = strdup(argv[i]);
+			udid = argv[i];
 			continue;
 		}
 		else if (!strcmp(argv[i], "-h") || !strcmp(argv[i], "--help")) {
@@ -67,15 +67,13 @@ int main(int argc, char **argv)
 	}
 
 	if (IDEVICE_E_SUCCESS != idevice_new(&device, udid)) {
-		printf("No device found, is it plugged in?\n");
 		if (udid) {
-			free(udid);
+			printf("No device found with udid %s, is it plugged in?\n", udid);
+		} else {
+			printf("No device found, is it plugged in?\n");
 		}
 		return -1;
 	}
-	if (udid) {
-		free(udid);
-	}
 
 	if (LOCKDOWN_E_SUCCESS != lockdownd_client_new_with_handshake(device, &lckd, NULL)) {
 		idevice_free(device);
@@ -83,10 +81,10 @@ int main(int argc, char **argv)
 		return -1;
 	}
 
-	lockdownd_start_service(lckd, "com.apple.mobile.screenshotr", &port);
+	lockdownd_start_service(lckd, "com.apple.mobile.screenshotr", &service);
 	lockdownd_client_free(lckd);
-	if (port > 0) {
-		if (screenshotr_client_new(device, port, &shotr) != SCREENSHOTR_E_SUCCESS) {
+	if (service && service->port > 0) {
+		if (screenshotr_client_new(device, service, &shotr) != SCREENSHOTR_E_SUCCESS) {
 			printf("Could not connect to screenshotr!\n");
 		} else {
 			char *imgdata = NULL;
@@ -115,8 +113,12 @@ int main(int argc, char **argv)
 	} else {
 		printf("Could not start screenshotr service! Remember that you have to mount the Developer disk image on your device if you want to use the screenshotr service.\n");
 	}
+
+	if (service)
+		lockdownd_service_descriptor_free(service);
+
 	idevice_free(device);
-	
+
 	return result;
 }
 
